@@ -178,7 +178,7 @@ about_cb (GtkWidget *widget, gpointer data)
                 NULL
         };
         /* Translator credits */
-        gchar *translator_credits = _("translator_credits");
+        gchar *translator_credits = _("translator-credits");
 
 	if (about != NULL) {
 		gtk_window_present (GTK_WINDOW(about));
@@ -204,7 +204,7 @@ about_cb (GtkWidget *widget, gpointer data)
 				 _("A worm game for GNOME."),
 				 (const char **)authors,
 				 (const char **)documenters,
-				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
    
 	if (pixbuf != NULL)
