@@ -276,9 +276,9 @@ tilepos cross_map [MAX_TILES] = {
  {13, 12,  4}, {13, 10,  4}, {9, 8,  4}, {11, 8,  4},
  {13, 8,  4}, {15, 8,  4}, {17, 8,  4}, {13, 6,  4},
  {13, 4,  4}, {5, 14,  3}, {21, 14,  3}, {13, 13,  3},
- {13, 11,  3}, {12, 9,  3}, {14, 9,  3}, {6, 8,  3},
- {8, 8, 3}, {10, 8,  3}, {12, 7,  3}, {14, 7,  3},
- {16, 8,  3}, {18, 8,  3}, {20, 8, 3}, {13, 5,  3},
+ {13, 11,  3}, {6, 8,  3},
+ {8, 8, 3}, {10, 8,  3}, {12, 9,  3}, {12, 7,  3}, {14, 9,  3}, {14, 7,  3},  {16, 8,  3}, {18, 8,  3}, {20, 8, 3},
+   {13, 5,  3},
  {13, 3,  3}, {5, 2,  3}, {21, 2,  3}, {5, 14,  2},
  {7, 14,  2}, {13, 14,  2}, {19, 14,  2}, {21, 14,  2},
  {5, 12,  2}, {13, 12,  2}, {21, 12,  2}, {13, 10, 2},
@@ -290,9 +290,9 @@ tilepos cross_map [MAX_TILES] = {
  {7, 14,  1}, {9, 14,  1}, {17, 14,  1}, {19, 14,  1},
  {21, 14,  1}, {13, 13,  1}, {5, 12,  1}, {7, 12, 1},
  {19, 12, 1}, {21, 12,  1}, {13, 11,  1}, {5, 10,  1},
- {21, 10,  1}, {12, 9,  1},  {14, 9,  1},  {4, 8,  1},
- {6, 8,  1}, {8, 8,  1}, {10, 8,  1}, {12, 7,  1},
- {14, 7,  1},  {16, 8,  1}, {18, 8,  1}, {20, 8,  1},
+ {21, 10,  1}, {4, 8,  1},
+ {6, 8,  1}, {8, 8,  1}, {10, 8,  1}, {12, 9,  1}, {12, 7,  1},
+ {14, 9,  1}, {14, 7,  1},  {16, 8,  1}, {18, 8,  1}, {20, 8,  1},
  {22, 8,  1}, {5, 6,  1}, {21, 6,  1}, {13, 5,  1},
  {5, 4,  1}, {7, 4, 1}, {19, 4, 1}, {21, 4,  1},
  {13, 3,  1}, {5, 2,  1}, {7, 2,  1}, {9, 2,  1},
@@ -708,16 +708,17 @@ static gchar *selected_tileset = NULL;
 struct _maps
 {
   gchar *name ;
+  gchar *score_name;
   tilepos *map ;
 } maps[] = {
-	{ N_("Easy"),      easy_map },
-	{ N_("Difficult"), hard_map },
-        { N_("Confounding Cross"),      cross_map },
-        { N_("Pyramid's Walls"),      pyramid_map },
-        { N_("Tic-Tac-Toe"),      tictactoe_map },
-        { N_("Cloud"),      cloud_map },
-        { N_("Red Dragon"),      reddragon_map },
-        { N_("Four Bridges"),      fourbridges_map },
+	{ N_("Easy"), "easy", easy_map },
+	{ N_("Difficult"), "difficult", hard_map },
+        { N_("Confounding Cross"), "confounding", cross_map },
+        { N_("Pyramid's Walls"), "pyramid", pyramid_map },
+        { N_("Tic-Tac-Toe"), "tictactoe", tictactoe_map },
+        { N_("Cloud"), "cloud", cloud_map },
+        { N_("Red Dragon"), "dragon", reddragon_map },
+        { N_("Four Bridges"), "bridges", fourbridges_map },
 
 };
 
@@ -815,8 +816,6 @@ GnomeUIInfo settingsmenu [] = {
 			       N_("Show or hide the toolbar"),
 			       show_tb_callback, NULL),
 
-	GNOMEUIINFO_SEPARATOR,
-
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM(properties_callback, NULL),
 	GNOMEUIINFO_END
 };
@@ -2016,6 +2015,20 @@ new_seed ()
 	next_seed = (guint) (t.tv_sec ^ t.tv_usec);
 }
 
+static void set_score_file (gchar * mapset)
+{
+	int i;
+
+	/* FIXME: This is a bit ugly, but we only save the name of the
+	   map (and it isn't suitable for generating the scorefile
+	   name. It's also a bit close to code freeze to introduce
+	   gratuitous changes so this is it. */
+	for (i=0; i<G_N_ELEMENTS(maps); i++) {
+		if (g_utf8_collate (mapset, maps[i].name) == 0)
+			score_current_mapset = maps[i].score_name;
+	}
+}
+
 void
 new_game (gboolean re_seed)
 {
@@ -2028,10 +2041,8 @@ new_game (gboolean re_seed)
 
 	init_game ();
 
-	if (score_current_mapset != NULL)
-		g_free (score_current_mapset);
+	set_score_file (mapset);
 
-	score_current_mapset = strdup (mapset);
 	update_score_state ();
 }
 
@@ -2174,7 +2185,7 @@ main (int argc, char *argv [])
 
 	do_game ();
 	init_game ();
-	score_current_mapset = g_strdup (mapset);
+	set_score_file (mapset);
 	update_score_state ();
 	
 	/* Note: we have to have a layout loaded before here so that the
